@@ -17,6 +17,7 @@ from django.views.generic import ListView
 from django import forms
 
 import datetime
+import inspect
 import time
 import re
 from decimal import Decimal
@@ -113,11 +114,14 @@ def get_custom_fields_from_model(model_class):
         custom_fields = CustomField.objects.filter(content_type=content_type)
         return custom_fields
 
+def isprop(v):
+    return isinstance(v, property)
+
 def get_properties_from_model(model_class):
     properties = []
-    for attr_name, attr in dict(model_class.__dict__).iteritems():
-        if type(attr) == property:
-            properties.append(dict(label=attr_name, name=attr_name.strip('_').replace('_',' ')))
+    attr_names = [name for (name, value) in inspect.getmembers(model_class, isprop)]
+    for attr_name in attr_names:
+        properties.append(dict(label=attr_name, name=attr_name.strip('_').replace('_',' ')))
     return sorted(properties)
 
 def filter_property(filter_field, value):
@@ -190,6 +194,7 @@ def filter_property(filter_field, value):
     return filtered 
 
             
+@staff_member_required
 def ajax_get_related(request):
     """ Get related model and fields
     Requires get variables model and field
@@ -225,6 +230,7 @@ def ajax_get_related(request):
         'path_verbose': path_verbose,
     }, RequestContext(request, {}),)
 
+@staff_member_required
 def ajax_get_fields(request):
     """ Get fields and properties for a particular model
     """
@@ -278,6 +284,7 @@ def ajax_get_fields(request):
         'root_model': root_model,
     }, RequestContext(request, {}),)
 
+@staff_member_required
 def ajax_get_choices(request):
     path_verbose = request.GET.get('path_verbose')
     label = request.GET.get('label')
@@ -287,6 +294,7 @@ def ajax_get_choices(request):
     options_html = select_widget.render_options([], [0])
     return HttpResponse(options_html)
 
+@staff_member_required
 def ajax_get_formats(request):
     choices = Format.objects.values_list('pk', 'name')
     select_widget = forms.Select(choices=[('','---------')] + list(choices))
@@ -331,7 +339,10 @@ def report_to_list(report, user, preview=False, queryset=None):
         try:
             objects = report.get_query()
         except exceptions.ValidationError, e:
-            message += "Validation Error: {0!s}. This probably means something is wrong with the report's filters.".format(e)
+            message += "Validation Error: {0!s}. Something may be wrong with the report's filters.".format(e)
+            return [], message
+        except ValueError, e:
+            message += "Value Error: {0!s}. Something may be wrong with the report's filters. For example it may be expecting a number but received a character.".format(e)
             return [], message
 
     # Display Values
@@ -664,7 +675,7 @@ def download_xlsx(request, pk, queryset=None):
     
     wb = Workbook()
     ws = wb.worksheets[0]
-    ws.title = report.name
+    ws.title = report.name[:30]
     filename = re.sub(r'\W+', '', report.name) + '.xlsx'
     
     i = 0
@@ -713,7 +724,7 @@ def create_copy(request, pk):
     """ Copy a report including related fields """
     report = get_object_or_404(Report, pk=pk)
     new_report = duplicate(report, changes=(
-        ('name', '{} (copy)'.format(report.name)),
+        ('name', '{0} (copy)'.format(report.name)),
         ('user_created', request.user),
         ('user_modified', request.user),
     ))
